
# Short names for engine directories:
%global engine_name ovirt-engine
%global engine_etc %{_sysconfdir}/%{engine_name}
%global engine_usr %{_datadir}/%{engine_name}
%global engine_var %{_var}/lib/%{engine_name}
%global engine_jar %{_javadir}/%{engine_name}
%global engine_tmp %{_var}/cache/%{engine_name}
%global engine_ear %{engine_usr}/engine.ear
%global engine_pki %{_sysconfdir}/pki/%{engine_name}
%global restapi_war %{engine_ear}/restapi.war
%global root_war %{engine_ear}/root.war

# The name of the engine user and group:
%global engine_user ovirt
%global engine_group ovirt
%global engine_uid 108

# Macro to create the engine user:
%global create_engine_user \
bin/getent group %{engine_group} >/dev/null || /sbin/groupadd -r %{engine_group}; \
/bin/getent passwd %{engine_user} >/dev/null || /sbin/useradd -c "oVirt Manager" -u %{engine_uid} -g %{engine_group} -M -d %{engine_var} %{engine_user}


Name: ovirt-engine
Version: 3.1.0
Release: 2%{?dist}
Summary: Management server for Open Virtualization
Group: Applications/System
License: ASL 2.0
URL: http://www.ovirt.org

Source0:  http://www.ovirt.org/releases/stable/src/%{name}-%{version}.tar.gz

# Update to Hibernate 3.6.10:
Patch10: %{name}-update-hibernate.patch

# Don't build the GWT components:
Patch20: %{name}-dont-build-gwt-components.patch

# Fix the checkstyle group, artifact and version:
Patch30: %{name}-fix-checkstyle-gav.patch

# Update to Spring 3:
# Upstream: http://gerrit.ovirt.org/3002
Patch40: %{name}-update-spring.patch

# Remove Spring from the RESTAPI:
# Upstream: http://gerrit.ovirt.org/1390
Patch50: %{name}-remove-spring-from-restapi.patch

# Remove the frontend related content from the ear:
Patch60: %{name}-remove-frontend-from-ear.patch

# Make the dependency on servlet API explicit in the module containing
# the health servlet:
Patch61: %{name}-make-dependency-on-servlet-api-explicit.patch

# Make dependency on commons-collections explicit:
# Upstream: http://gerrit.ovirt.org/6597
Patch70: %{name}-make-dependency-on-commons-collections-explicit.patch

# Update to commons-configuration 1.8:
Patch80: %{name}-update-commons-configuration.patch

# Create the sysctl.conf file if it doesn't exist:
Patch90: %{name}-create-sysctl-config-if-it-doesnt-exist.patch

# Fix building of classpaths using commons as the "apache-" symlink is being
# removed:
Patch100: %{name}-fix-commons-classpath-building.patch

# Add a README file:
Patch110: %{name}-add-readme.patch

# Replace the index page with one that doesn't include links to the user portal
# or webadmin:
Patch120: %{name}-replace-index-page.patch

# Don't try to lock the frontend packages, as they are not provided in
# Fedora yet:
Patch130: %{name}-dont-try-to-lock-frontend-packages.patch

# Check for PostgreSQL version 9, not 9.1:
Patch200: %{name}-check-for-postgresql-9-not-91.patch
Patch210: %{name}-updated-allinone-plugin-for-new-security-model.patch
Patch220: %{name}-use-pid-instead-of-procpid.patch


BuildArch: noarch

# Build time requirements:
BuildRequires: apache-commons-beanutils
BuildRequires: apache-commons-codec
BuildRequires: apache-commons-collections
BuildRequires: apache-commons-configuration
BuildRequires: apache-commons-jxpath
BuildRequires: apache-commons-lang
BuildRequires: apache-commons-logging
BuildRequires: apache-mina
BuildRequires: apache-sshd
BuildRequires: bea-stax-api
BuildRequires: checkstyle
BuildRequires: dos2unix
BuildRequires: jackson
BuildRequires: hibernate-commons-annotations
BuildRequires: hibernate-jpa-2.0-api
BuildRequires: hibernate-validator
BuildRequires: hibernate3
BuildRequires: jakarta-commons-httpclient
BuildRequires: java-devel
BuildRequires: javamail
BuildRequires: javassist
BuildRequires: jboss-annotations-1.1-api
BuildRequires: jboss-ejb-3.1-api
BuildRequires: jboss-logging
BuildRequires: jboss-interceptors-1.1-api
BuildRequires: jboss-jacc-1.4-api
BuildRequires: jboss-servlet-3.0-api
BuildRequires: jpackage-utils
BuildRequires: jsch
BuildRequires: log4j
BuildRequires: make
BuildRequires: maven
BuildRequires: maven-antrun-plugin
BuildRequires: maven-assembly-plugin
BuildRequires: maven-checkstyle-plugin
BuildRequires: maven-clean-plugin
BuildRequires: maven-compiler-plugin
BuildRequires: maven-dependency-plugin
BuildRequires: maven-ear-plugin
BuildRequires: maven-eclipse-plugin
BuildRequires: maven-ejb-plugin
BuildRequires: maven-jar-plugin
BuildRequires: maven-jaxb2-plugin
BuildRequires: maven-javadoc-plugin
BuildRequires: maven-plugin-exec
BuildRequires: maven-resources-plugin
BuildRequires: maven-source-plugin
BuildRequires: maven-surefire-plugin
BuildRequires: maven-war-plugin
BuildRequires: postgresql-jdbc
BuildRequires: quartz
BuildRequires: resteasy
BuildRequires: springframework-instrument
BuildRequires: springframework-jdbc
BuildRequires: spring-ldap
BuildRequires: xmlrpc3-client
BuildRequires: unzip

# Run time requirements (most of these requirements should be
# moved to the subpackages):
Requires: bea-stax-api
Requires: bind-utils
Requires: cracklib-python
Requires: geronimo-validation
Requires: hibernate-commons-annotations
Requires: hibernate-jpa-2.0-api
Requires: hibernate-validator
Requires: httpd
Requires: jakarta-commons-httpclient
Requires: java
Requires: jboss-interceptors-1.1-api
Requires: jboss-logging
Requires: jpackage-utils
Requires: log4j
Requires: mod_ssl
Requires: ntp
Requires: openssl
Requires: policycoreutils-python
Requires: postgresql-jdbc
Requires: vdsm-bootstrap
Requires: yum-plugin-versionlock

# For local database:
Requires: postgresql-server >= 8.4.7
Requires: postgresql-contrib >= 8.4.7

# Require JBoss AS 7:
Requires: jboss-as >= 7.1.1-6

# We can't require exactly the same version and release of the
# setup package because it needs to be updated independely as part
# of the update process implemented in the engine-upgrade script:
Requires: %{name}-setup >= %{version}-%{release}

# Require the subpackages so that everything is installed when the
# main package is installed:
Requires: %{name}-backend = %{version}-%{release}
Requires: %{name}-restapi = %{version}-%{release}
Requires: %{name}-config = %{version}-%{release}
Requires: %{name}-notification-service = %{version}-%{release}
Requires: %{name}-dbscripts = %{version}-%{release}

# These packages are not available in Fedora yet:
#Requires: ovirt-iso-uploader
#Requires: ovirt-image-uploader
#Requires: ovirt-log-collector


%description
oVirt Engine is a feature-rich server virtualization management
system that provides advanced capabilities for managing the Open
virtualization infrastructure for Servers and Desktops.


%package backend
Summary: Engine core of oVirt Engine
Group: Applications/System
Requires: %{name} = %{version}-%{release}
Requires: antlr-tool
Requires: aopalliance
Requires: apache-commons-beanutils
Requires: apache-commons-codec
Requires: apache-commons-collections
Requires: apache-commons-lang
Requires: apache-mina
Requires: apache-sshd
Requires: bea-stax-api
Requires: dom4j
Requires: geronimo-validation
Requires: jackson
Requires: jakarta-commons-httpclient
Requires: java
Requires: javassist
Requires: jboss-interceptors-1.1-api
Requires: jsch
Requires: objectweb-asm
Requires: openssh
Requires: openssl
Requires: picketbox
Requires: quartz
Requires: slf4j
Requires: springframework
Requires: springframework-aop
Requires: springframework-beans
Requires: springframework-context
Requires: springframework-instrument
Requires: springframework-jdbc
Requires: springframework-tx
Requires: spring-ldap
Requires: ws-commons-util
Requires: xmlrpc3-client
Requires: xmlrpc3-common


%description backend
The backend engine of oVirt Engine


%package restapi
Summary: RESTful API for oVirt Engine
Group: Applications/System
Requires: %{name} = %{version}-%{release}

%description restapi
The RESTful API for oVirt Engine


%package setup
Summary: Setup and upgrade scripts for oVirt Engine
Group: Applications/System
Requires: %{name}
Requires: lsof
Requires: nfs-utils

%description setup
Setup and upgrade scripts for oVirt Engine


%package dbscripts
Summary: Database scripts for oVirt Engine
Group: Applications/System
Requires: %{name}

%description dbscripts
Database scripts for oVirt Engine


%package tools-common
Summary: Common libraries for  oVirt Engine Tools
Group: Applications/System
Requires: %{name} = %{version}-%{release}
Requires: apache-commons-collections
Requires: apache-commons-logging
Requires: apache-commons-lang
Requires: apache-commons-codec
Requires: apache-commons-configuration
Requires: apache-commons-jxpath
Requires: log4j

%description tools-common
The common libraries used by oVirt Engine Tools


%package notification-service
Summary: Notification service for oVirt Engine Tools
Group: Applications/System
Requires: %{name} = %{version}-%{release}
Requires: %{name}-tools-common = %{version}-%{release}
Requires: classpathx-mail

%description notification-service
The notification service used by oVirt Engine


%package config
Summary: Configuration tool for oVirt Engine
Group: Applications/System
Requires: %{name}-tools-common = %{version}-%{release}

%description config
The configuration tool for oVirt Engine


%package setup-plugin-allinone
Summary: All-in-one plugin for oVirt Engine's setup
Group: Applications/System
Requires: %{name}-setup
Requires: %{name}-sdk >= 3.2
Requires: vdsm

%description setup-plugin-allinone
All-in-one plugin for oVirt Engine's setup


%prep

# Unpack and patch the sources:
%setup -q -c -n %{name}-%{version}

# Adjustments for Fedora:
%patch10 -p1
%patch20 -p1
%patch30 -p1
%patch40 -p1
%patch50 -p1
%patch60 -p1
%patch61 -p1
%patch70 -p1
%patch80 -p1
%patch90 -p1
%patch100 -p1
%patch110 -p1
%patch120 -p1
%patch130 -p1

# Backports and fixes:
%patch200 -p1
%patch210 -p1
%patch220 -p1


%build

# Use the makefile to do build, but instructing it to use mvn-rpmbuild instead
# of regular mvn and to skip completely the tests, as we don't have the
# required dependencies:
make \
  MVN="mvn-rpmbuild" \
  PREFIX="%{buildroot}" \
  BUILD_FLAGS="-Dmaven.test.skip=true -Dproject.build.sourceEncoding=ISO-8859-1 javadoc:aggregate" \
  build_mvn


%install

# Use the makefile to do the normal installation, after that we
# will need to replace jar files with links to their actual
# locations:
make PREFIX=%{buildroot} SOURCE_DIR=%{_sourcedir} install

# Create the directories required for jar and POM files:
install -d -m 755 %{buildroot}%{engine_jar}
install -d -m 755 %{buildroot}%{_mavenpomdir}
install -d -m 755 %{buildroot}%{_javadocdir}/%{name}

# Jar and POM files:
while read module_path artifact_id
do
  pom_file="${module_path}/pom.xml"
  jar_file="${module_path}/target/${artifact_id}-%{version}.jar"
  install -p -m 644 ${pom_file} %{buildroot}%{_mavenpomdir}/JPP.%{name}-${artifact_id}.pom
  if [ -f "${jar_file}" ]
  then
    install -p -m 644 ${jar_file} %{buildroot}%{engine_jar}/${artifact_id}.jar
    %add_maven_depmap JPP.%{name}-${artifact_id}.pom %{name}/${artifact_id}.jar
  else
    %add_maven_depmap JPP.%{name}-${artifact_id}.pom
  fi
done <<'.'
. parent
backend backend
backend/manager manager
backend/manager/modules manager-modules
backend/manager/modules/compat compat
backend/manager/modules/engineencryptutils engineencryptutils
backend/manager/modules/common common
backend/manager/modules/utils utils
backend/manager/modules/dal dal
backend/manager/modules/vdsbroker vdsbroker
backend/manager/modules/searchbackend searchbackend
backend/manager/modules/beans manager-beans
backend/manager/modules/beans/scheduler scheduler
backend/manager/modules/bll bll
backend/manager/modules/restapi restapi-parent
backend/manager/modules/restapi/interface restapi-interface
backend/manager/modules/restapi/interface/definition restapi-definition
backend/manager/modules/restapi/interface/common/jaxrs interface-common-jaxrs
backend/manager/modules/restapi/types restapi-types
backend/manager/modules/restapi/jaxrs restapi-jaxrs
backend/manager/tools manager-tools
backend/manager/tools/engine-tools-common engine-tools-common
backend/manager/tools/engine-config engine-config
backend/manager/tools/engine-notifier engine-notifier
backend/manager/tools/engine-notifier/engine-notifier-service engine-notifier-service
backend/manager/tools/engine-notifier/engine-notifier-resources engine-notifier-resources
.

# Remove all the .jar files from the .ear, as we will replace them with links
# to their actual locations:
find %{buildroot}%{engine_ear} -depth -name '*.jar' -exec rm -rf {} \;

# Replace jar files in the ear with links to their actuals
# locations, first for jar files from this package, as for these
# can't use build-classpath:
while read jar_name ear_path
do
  ln -s %{engine_jar}/${jar_name}.jar %{buildroot}%{engine_ear}/${ear_path}.jar
done <<'.'
bll engine-bll
scheduler engine-scheduler
common lib/engine-common
compat lib/engine-compat
dal lib/engine-dal
engineencryptutils lib/engine-encryptutils
engine-tools-common lib/engine-tools-common
utils lib/engine-utils
vdsbroker lib/engine-vdsbroker
searchbackend lib/searchbackend
.

# Then for the system jar files (using build-classpath):
while read jar_name lib_path
do
  ln -s `build-classpath ${jar_name}` %{buildroot}%{engine_ear}/lib/${lib_path}.jar
done <<'.'
apache-mina/mina-core mina-core
apache-sshd/sshd-core sshd-core
commons-beanutils commons-beanutils
commons-codec commons-codec
commons-collections commons-collections
commons-httpclient commons-httpclient
commons-lang commons-lang
dom4j dom4j
geronimo-validation validation-api
hibernate/hibernate-commons-annotations hibernate-commons-annotations
hibernate-validator hibernate-validator
jsch jsch
objectweb-asm/asm-all asm-all
quartz quartz
slf4j/api slf4j-api
springframework/spring-aop spring-aop
springframework/spring-beans spring-beans
springframework/spring-context spring-context
springframework/spring-core spring-core
springframework/spring-expression spring-expression
springframework/spring-instrument spring-instrument
springframework/spring-jdbc spring-jdbc
springframework/spring-tx spring-tx
spring-ldap/spring-ldap-core spring-ldap-core
ws-commons-util ws-commons-util
xmlrpc3-client xmlrpc-client
xmlrpc3-common xmlrpc-common
.

# Replace jar files in the RESTAPI web application with links to ther
# actual locations, first for jar files from this package, as for these
# can't use build-classpath:
while read jar_name lib_path
do
  ln -s %{engine_jar}/${jar_name}.jar %{buildroot}%{restapi_war}/WEB-INF/lib/${lib_path}.jar
done <<'.'
interface-common-jaxrs interface-common-jaxrs
restapi-definition restapi-definition
restapi-jaxrs restapi-jaxrs
restapi-types restapi-types
.

# Then for the system jar files (using build-classpath):
while read jar_name lib_path
do
  ln -s `build-classpath ${jar_name}` %{buildroot}%{restapi_war}/WEB-INF/lib/${lib_path}.jar
done <<'.'
nakeyaml snakeyaml
.

%preun
if [ "$1" -eq 0 ]
then
    curdate=`date +"%Y_%m_%d_%H_%M_%%S"`
    if [[ -d %{_sysconfdir}/pki/%{engine_name} ]]; then
        mkdir -p %{_sysconfdir}/pki/%{engine_name}-backups/%{engine_name}-${curdate}
        #backup whole 'rhevm' dir into the backup dir with current date
        cp -pR %{_sysconfdir}/pki/%{engine_name}/ %{_sysconfdir}/pki/%{engine_name}-backups/%{engine_name}-${curdate}/
    fi
fi


%postun
if [ "$1" -eq 0 ]
then
    if [[ -d %{_sysconfdir}/pki/%{engine_name} ]]; then
	    rm -rf %{_sysconfdir}/pki/%{engine_name}
	fi

    if [[ -f %{_sysconfdir}/yum/pluginconf.d/versionlock.list ]]
    then
        sed -i '/ovirt/d' %{_sysconfdir}/yum/pluginconf.d/versionlock.list
    fi
fi


%pre
%create_engine_user


%pre backend
%create_engine_user


%pre notification-service
%create_engine_user


%files

# The main package owns most of the directories:
%dir %{engine_usr}
%dir %{engine_usr}/ovirt-isos
%dir %{engine_usr}/resources
%dir %{engine_usr}/db-backups
%dir %{engine_usr}/scripts
%dir %{_localstatedir}/run/%{engine_name}
%dir %attr(-, %{engine_user}, %{engine_group}) %{_var}/log/%{engine_name}
%dir %attr(-, %{engine_user}, %{engine_group}) %{_var}/lock/%{engine_name}

# VDS installer script:
%{engine_usr}/scripts/vds_installer.py*

# Log rotation script:
%{engine_usr}/scripts/ovirtlogrot.sh
%{_sysconfdir}/cron.daily/ovirt-cron

# Misc configuration files:
%{engine_usr}/conf
%{_sysconfdir}/tmpfiles.d/ovirt-engine.conf

# Engine configuration files:
%dir %attr(-, %{engine_user}, %{engine_group}) %{engine_etc}
%config(noreplace) %attr(-, %{engine_user}, %{engine_group}) %{engine_etc}/engine.conf
%config(noreplace) %{engine_etc}/web-conf.js

# Files needed by the service:
%config(noreplace) %{_sysconfdir}/sysconfig/%{engine_name}
%config(noreplace) %attr(-, %{engine_user}, %{engine_group}) %{engine_etc}/engine-service.xml
%config(noreplace) %{_sysconfdir}/security/limits.d/10-ovirt-engine.conf
%attr(-, %{engine_user}, %{engine_group}) %{engine_etc}/engine-service-logging.properties
%attr(-, %{engine_user}, %{engine_group}) %{engine_etc}/engine-service-users.properties
%{engine_usr}/scripts/engine-service.py*
%{_unitdir}/%{engine_name}.service

# Jar files used by all the components:
%dir %{engine_jar}
%{engine_jar}/common.jar
%{engine_jar}/compat.jar
%{engine_jar}/utils.jar

# POM files:
%{_mavendepmapfragdir}/%{name}
%{_mavenpomdir}/JPP.%{name}-parent.pom
%{_mavenpomdir}/JPP.%{name}-common.pom
%{_mavenpomdir}/JPP.%{name}-compat.pom
%{_mavenpomdir}/JPP.%{name}-utils.pom

# Documentation:
%doc LICENSE


%files backend

# Jar files:
%{engine_jar}/bll.jar
%{engine_jar}/dal.jar
%{engine_jar}/engine-config.jar
%{engine_jar}/engineencryptutils.jar
%{engine_jar}/scheduler.jar
%{engine_jar}/searchbackend.jar
%{engine_jar}/vdsbroker.jar

# POM files:
%{_mavenpomdir}/JPP.%{name}-backend.pom
%{_mavenpomdir}/JPP.%{name}-manager.pom
%{_mavenpomdir}/JPP.%{name}-manager-beans.pom
%{_mavenpomdir}/JPP.%{name}-manager-modules.pom
%{_mavenpomdir}/JPP.%{name}-manager-tools.pom
%{_mavenpomdir}/JPP.%{name}-bll.pom
%{_mavenpomdir}/JPP.%{name}-dal.pom
%{_mavenpomdir}/JPP.%{name}-engine-config.pom
%{_mavenpomdir}/JPP.%{name}-engine-notifier-resources.pom
%{_mavenpomdir}/JPP.%{name}-engine-notifier-service.pom
%{_mavenpomdir}/JPP.%{name}-engineencryptutils.pom
%{_mavenpomdir}/JPP.%{name}-scheduler.pom
%{_mavenpomdir}/JPP.%{name}-searchbackend.pom
%{_mavenpomdir}/JPP.%{name}-vdsbroker.pom

# Directories for the deployments, contents and temporary files need to
# be owned by the engine user because the application server needs to
# write to them:
%attr(-, %{engine_user}, %{engine_group}) %{engine_var}
%attr(-, %{engine_user}, %{engine_group}) %{engine_tmp}

# The backend owns the directory of the ear and most of its contents,
# but not all, as most of the web applications are owned by other
# subpackages:
%dir %{engine_ear}
%{engine_ear}/META-INF
%{engine_ear}/lib
%{engine_ear}/engine-bll.jar
%{engine_ear}/engine-scheduler.jar
%{engine_ear}/ovirtengineweb.war

# Root web application:
%{root_war}

# Sysprep files:
%config(noreplace) %{engine_etc}/sysprep

# PKI directories are owned by the engine user because it needs to
# create files inside:
%dir %attr(-, %{engine_user}, %{engine_group}) %{engine_pki}
%dir %attr(-, %{engine_user}, %{engine_group}) %{engine_pki}/certs
%dir %attr(-, %{engine_user}, %{engine_group}) %{engine_pki}/keys
%dir %attr(-, %{engine_user}, %{engine_group}) %{engine_pki}/private
%dir %attr(-, %{engine_user}, %{engine_group}) %{engine_pki}/requests

# PKI scripts:
%{engine_pki}/*.sh
%{engine_pki}/generate-ssh-keys

# PKI configuration files:
%config(noreplace) %{engine_pki}/openssl.conf
%config(noreplace) %{engine_pki}/cacert.template
%config(noreplace) %{engine_pki}/cert.template

# The certificate database files:
%config(noreplace) %attr(-, %{engine_user}, %{engine_group}) %{engine_pki}/database.txt
%config(noreplace) %attr(-, %{engine_user}, %{engine_group}) %{engine_pki}/serial.txt

# Modules:
%{engine_usr}/modules


%files setup

# Links to the main programs:
%{_bindir}/engine-setup
%{_bindir}/engine-upgrade
%{_bindir}/engine-check-update
%{_bindir}/engine-cleanup

# Python scripts:
%{engine_usr}/scripts/basedefs.py*
%{engine_usr}/scripts/engine_validators.py*
%{engine_usr}/scripts/setup_params.py*
%{engine_usr}/scripts/setup_sequences.py*
%{engine_usr}/scripts/setup_controller.py*
%{engine_usr}/scripts/common_utils.py*
%{engine_usr}/scripts/output_messages.py*
%{engine_usr}/scripts/nfsutils.py*
%{engine_usr}/scripts/engine-setup.py*
%{engine_usr}/scripts/engine-cleanup.py*
%{engine_usr}/scripts/engine-upgrade.py*
%{engine_usr}/scripts/post_upgrade.py*

# Plugins directory:
%dir %{engine_usr}/scripts/plugins
%{engine_usr}/scripts/plugins/example_plugin_000.py*


%files setup-plugin-allinone
%{engine_usr}/scripts/plugins/all_in_one_100.py*


%files dbscripts
%{engine_usr}/dbscripts


%files restapi

# Jar files:
%{engine_jar}/interface-common-jaxrs.jar
%{engine_jar}/restapi-definition.jar
%{engine_jar}/restapi-jaxrs.jar
%{engine_jar}/restapi-types.jar

# POM files:
%{_mavenpomdir}/JPP.%{name}-interface-common-jaxrs.pom
%{_mavenpomdir}/JPP.%{name}-restapi-definition.pom
%{_mavenpomdir}/JPP.%{name}-restapi-interface.pom
%{_mavenpomdir}/JPP.%{name}-restapi-jaxrs.pom
%{_mavenpomdir}/JPP.%{name}-restapi-parent.pom
%{_mavenpomdir}/JPP.%{name}-restapi-types.pom

# Everything inside of the web application is owned by this
# subpackage:
%{restapi_war}


%files tools-common

# Jar files:
%{engine_jar}/engine-tools-common.jar

# POM files:
%{_mavenpomdir}/JPP.%{name}-engine-tools-common.pom


%files config

# Links to the main scripts:
%{_bindir}/engine-config
%{_bindir}/engine-manage-domains

# Scripts:
%{engine_usr}/engine-config
%{engine_usr}/engine-manage-domains
%{engine_usr}/kerberos

# Configuration files for the configuration tool:
%dir %{engine_etc}/engine-config
%{engine_etc}/engine-config/engine-config.conf
%{engine_etc}/engine-config/engine-config.*properties
%{engine_etc}/engine-config/log4j.xml

# Configuration files for the domain management tool:
%dir %{engine_etc}/engine-manage-domains
%{engine_etc}/engine-manage-domains/engine-manage-domains.conf
%{engine_etc}/engine-manage-domains/log4j.xml


%files notification-service

# Startup scripts:
%{_datadir}/%{engine_name}/notifier
%{_initddir}/engine-notifierd

# Log and state directories must be owned by ovirt because the notifier service
# runs with that user and needs to write them:
%dir %attr(-, %{engine_user}, %{engine_group}) %{_var}/log/%{engine_name}/notifier
%dir %attr(-, %{engine_user}, %{engine_group}) %{_localstatedir}/run/%{engine_name}/notifier

# Configuration files:
%dir %{engine_etc}/notifier
%config(noreplace) %attr(-, %{engine_user}, %{engine_group}) %{engine_etc}/notifier/notifier.conf
%{engine_etc}/notifier/log4j.xml

# Jar files:
%{engine_jar}/engine-notifier-service.jar

# POM files:
%{_mavenpomdir}/JPP.%{name}-engine-notifier.pom


%changelog
* Thu Dec 06 2012 Juan Hernandez <juan.hernandez@redhat.com> - 3.1.0-2
- Check for PostgreSQL 9 instead of 9.1 (#884444)
- Update all in one plugin for new security model (#869457)
- Use pid instead of procpid in engine-cleanup
- Don't try to lock frontend packages
- Include the health servlet in the build

* Thu Aug 09 2012 Juan Hernandez <juan.hernandez@redhat.com> - 3.1.0-1
- Update to upstream 3.1 release

* Fri Aug 07 2012 Juan Hernandez <juan.hernandez@redhat.com> - 3.1.0-0.1.20120701git95220c
- Update to upstream 3.1 pre-release

* Tue Apr 24 2012 Juan Hernandez <juan.hernandez@redhat.com> - 3.0.0.0001-12
- Fixes needed to work with the jboss-as package
- Added systemd service files

* Thu Apr 12 2012 Juan Hernandez <juan.hernandez@redhat.com> - 3.0.0.0001-11
- Moved the upstream release number to the version tag

* Thu Apr 12 2012 Juan Hernandez <juan.hernandez@redhat.com> - 3.0.0.0001-10
- Remove license header from the spec
- Use global instead of define
- Don't use include for subpackages
- Don't use dangerous commands in scripts

* Sun Apr 01 2012 Juan Hernandez <juan.hernandez@redhat.com> - 3.0.0.0001-9
- Use the name macro to build the url
- Move sysprep files to the /etc directory
- Added javadoc subpackage
- Move the upstream release number to the release tag
- Use an standard software group

* Wed Mar 28 2012 Juan Hernandez <juan.hernandez@redhat.com> - 3.0.0.0001-8
- Make main package require the subpackages

* Wed Mar 28 2012 Juan Hernandez <juan.hernandez@redhat.com> - 3.0.0.0001-7
- Make setup subpackage depend on the dbscripts subpackage

* Mon Mar 26 2012 Juan Hernandez <juan.hernandez@redhat.com> - 3.0.0.0001-6
- Cleanup of the spec file

* Mon Mar 26 2012 Juan Hernandez <juan.hernandez@redhat.com> - 3.0.0.0001-5
- Replaced geronimo and tomcat API packages with equivalent jboss packages
- Removed c3p0 and snakeyml dependencies

 Thu Mar 15 2012 Juan Hernandez <juan.hernandez@redhat.com> - 3.0.0.0001-4
- Adjusted to build in Fedora from source

* Wed Jan 04 2012 Ronen Angluster <ranglust@redhat.com> - 3.0.0.0001-3
- Adjust code for Jboss AS 7.1

* Sun Dec 11 2011 Ronen Angluster <ranglust@redhat.com> - 3.0.0.0001-2
- Moved all hard coded paths to macros

* Wed Oct 26 2011 Ronen Angluster <ranglust@redhat.com> - 3.0.0.0001-1
- Initial build
- Cloned from RHEVM spec file
